****** Written by Marius Hagen and André Anundsen
****** The code estimates alternative hedonic models for rental prices in the office market. Results are saved in a table in LaTex format
****** In addition, the code estimates hedonic rental price indices for different geographical segments of the Oslo market
clear all
cd "$dataPath"
set maxvar 32000
use data_construtced_w_metro_dist_trunc, clear

** Keeping only contracts for offices in buildings with at least 5 transactions 
bysort building_id : gen num_trans = _N
keep if num_trans >= 5

** Extend martix size to be able to add more controls
set matsize 10000
sort contract_start_year

g three_digits = (zip_code < 1000)
g two_zip = int(zip_code/100)
g three_zip = int(zip_code/10)

** Only time and zip code
** Controlling for building fixed effects (note: do not need zip-code FE in this case, since location of buliding is not changing --> part of building FE)
global extended_controls i.contract_start_quarter_year lsize i.dum_private_renter contract_length_year i.renegotiated i.building_id


** Labeling variables for table
label var lsize "log(Size)"
label var contract_length_year "Contract length (year)"
label var shortest_dist_to_metro "Dist. to closest metro. (km)"
label define dum_private_renter 1 "Private renter"
label val dum_private_renter dum_private_renter
label define renegotiated 1 "Renegotiation"
label val renegotiated renegotiated

qui reg lrent $extended_controls
matrix b = e(b)'
svmat b
matrix bxi = b`i'["176.contract_start_quarter_year".."235.contract_start_quarter_year",1]
svmat bxi


matrix c = e(V)'
matrix d = vecdiag(c)
mat e = d
forval i = 1/`=rowsof(d)'{
forval j = 1/`=colsof(d)'{
mat e[`i',`j'] = sqrt(d[`i',`j'])
}
}
mat f = e'
svmat f

gen rent_index  = exp(bxi)
gen rent_index_plus_2se  = exp(bxi+f1)
gen rent_index_minus_2se  = exp(bxi-f1)
keep rent_index*
keep if rent_index != .
gen dup = _n 
gen contract_start_quarter_year = 176
replace contract_start_quarter_year = contract_start_quarter_year + dup - 1 if dup > 1
tsset contract_start_quarter_year
format contract_start_quarter_year %tq
drop dup
tssmooth ma ma_rent_index  = rent_index, window(3 1 0)
tssmooth ma ma_rent_index_minus_2se  = rent_index_minus_2se, window(3 1 0)
tssmooth ma ma_rent_index_plus_2se   = rent_index_plus_2se, window(3 1 0)
save hedonic_with_se, replace

line (ma_rent_index ma_rent_index_plus_2se  ma_rent_index_minus_2se) contract_start_quarter_year, xtitle("") ytitle("Prisindeks")

****** Written by Marius Hagen and André Anundsen
****** The code plots median, mean and hedonic indices (normalized to be 1 in 2005q1) for different geographical segments of the Oslo market
cd "$dataPath"
clear all
use MeanMedian
keep ma_mean_rent_all ma_median_rent_all contract_start_quarter_year
merge 1:1 contract_start_quarter_year using hedonic_with_se
drop _merge 
ren (ma_mean_rent_all ma_median_rent_all) (ma_mean_rent_all ma_median_rent)

sum  ma_mean_rent if contract_start_quarter_year == 180, meanonly
scalar norm_mean = r(mean)
g ma_mean_rent_norm = ma_mean_rent/norm_mean

sum  ma_median_rent if contract_start_quarter_year == 180, meanonly
scalar norm_median = r(mean)
g ma_median_rent_norm = ma_median_rent/norm_median

sum  ma_rent_index if contract_start_quarter_year == 180, meanonly
scalar norm_index = r(mean)
g ma_rent_index_norm = ma_rent_index/norm_index

g scaling_var = ma_rent_index_norm/ma_rent_index

g ma_rent_index_norm_plus_2se = scaling_var*ma_rent_index_plus_2se
g ma_rent_index_norm_minus_2se = scaling_var*ma_rent_index_minus_2se


label var ma_mean_rent_norm "Mean"
label var ma_median_rent_norm "Median"
label var ma_rent_index_norm "Hedonic"
label var ma_rent_index_norm_plus_2se "Hedonic +"
label var ma_rent_index_norm_minus_2se "- 1*SE"
keep if contract_start_quarter_year >= 180

line (ma_mean_rent_norm ma_median_rent_norm ma_rent_index_norm ma_rent_index_norm_plus_2se ma_rent_index_norm_minus_2se) contract_start_quarter_year , lcolor(red blue black) lpattern(dash longdash solid) legend(col(3) region(lstyle(none))) xla(180 196 212 228) xtitle("")

twoway line ma_rent_index_norm  contract_start_quarter_year , color(black)   lpattern(solid) || ///
	   line ma_mean_rent_norm contract_start_quarter_year , color(blue)   lpattern(dash) || ///
	   line ma_median_rent_norm contract_start_quarter_year , color(green)   lpattern(longdash) || ///
       rarea ma_rent_index_norm_plus_2se ma_rent_index_norm_minus_2se contract_start_quarter_year , fcolor(red%50) lcolor(white) legend(col(2)) legend(region(lcolor(white)))  xla(180 196 212 228) xtitle("")
			  
			  
			


