****** Written by Marius Hagen and André Anundsen
****** The code estimates alternative hedonic models for rental prices in the office market in Oslo. Results are saved in a table in LaTex format
****** In addition, the code estimates hedonic rental price indices for different geographical segments of the Oslo market
clear all
cd "$dataPath"
set maxvar 32000
use data_construtced_w_metro_dist_trunc, clear

** Keeping only contracts for offices in buildings with at least 5 transactions 
bysort building_id : gen num_trans = _N
keep if num_trans >= 5

** Extend martix size to be able to add more controls
set matsize 10000
sort contract_start_year

g three_digits = (zip_code < 1000)
g two_zip = int(zip_code/100)
g three_zip = int(zip_code/10)

** Only time and zip code
global simple_controls   i.zip_code i.contract_start_quarter_year 
global simple_controls2  i.two_zip i.contract_start_quarter_year 
global simple_controls3  i.three_zip i.contract_start_quarter_year 
global simple_controls4  i.contract_start_quarter_year 
** Baseline hedonic controls
global baseline_controls   i.zip_code i.contract_start_quarter_year lsize i.dum_private_renter contract_length_year i.renegotiated
** Adding distance to closest metro station to study effect of proximity to metro station
global additional_controls i.zip_code i.contract_start_quarter_year lsize i.dum_private_renter contract_length_year i.renegotiated shortest_dist_to_metro 
** Controlling for building fixed effects (note: do not need zip-code FE in this case, since location of buliding is not changing --> part of building FE)
global extended_controls i.contract_start_quarter_year lsize i.dum_private_renter contract_length_year i.renegotiated i.building_id
** Extended control excluding dummy for private renters
global extended_controls_excl_private i.contract_start_quarter_year lsize contract_length_year i.renegotiated i.building_id


** Labeling variables for table
label var lsize "log(Size (sq.ft.)"
label var contract_length_year "Contract length (year)"
label var shortest_dist_to_metro "Dist. to closest metro sta. (miles)"
label define dum_private_renter 1 "Private renter"
label val dum_private_renter dum_private_renter
label define renegotiated 1 "Renegotiation"
label val renegotiated renegotiated


*** Estimating four alternative hedonic models
qui reg lrent $simple_controls 
eststo output1
qui reg lrent $baseline_controls 
eststo output2
qui reg lrent $additional_controls
eststo output3
qui reg lrent $extended_controls
eststo output4
qui reg lrent $simple_controls2
eststo output5
qui reg lrent $simple_controls3
eststo output6
qui reg lrent $simple_controls4 
eststo output7

cd "$outputTables"
	esttab output7 output1 output2 output3 output4 using Table_hedonic.tex , keep(lsize contract_length_year 1.dum_private_renter 1.renegotiated shortest_dist_to_metro ) f replace ///
	b(3) se(2) sfmt(2) noobs se label  mtitles("(I)" "(II)" "(III)" "(IV)" "V") star(* 0.10 ** 0.05 *** 0.01) nonum type     	

	esttab output7 output1 output2 output3 output4 using Table_hedonic.tex, drop(*) f a 	noobs nomtitles nonum wrap nogaps

	esttab output7 output1 output2 output3 output4 using Table_hedonic.tex, drop(*) f a ///
	noobs scalars("N Observations" "r2_a R2") nomtitles nonum wrap nolines nogaps
	
	
cd "$outputTables"
	esttab output5 output6 output1 using Table_hedonic_zip.tex , keep( ) f replace ///
	b(3) se(2) sfmt(2) noobs se label  mtitles("(I)" "(II)" "(III)") star(* 0.10 ** 0.05 *** 0.01) nonum type     	

	esttab output5 output6 output1 using Table_hedonic_zip.tex, drop(*) f a 	noobs nomtitles nonum wrap nogaps

	esttab output5 output6 output1 using Table_hedonic_zip.tex, drop(*) f a ///
	noobs scalars("N Observations" "r2_a R2") nomtitles nonum wrap nolines nogaps
	
*** Estimating hedonic models for private and public tenants, separatly 
eststo clear
qui reg lrent $extended_controls
eststo output1
qui reg lrent $extended_controls_excl_private if dum_private_renter ==1
eststo output2
qui reg lrent $extended_controls_excl_private if dum_private_renter ==0
eststo output3

cd "$outputTables"
	esttab output1 output2 output3 using Table_hedonic_tenant.tex , keep(lsize contract_length_year 1.dum_private_renter 1.renegotiated ) f replace ///
	b(3) se(2) sfmt(2) noobs se label  mtitles("(I)" "(II)" "(III)" "(IV)" "V") star(* 0.10 ** 0.05 *** 0.01) nonum type     	

	esttab output1 output2 output3 using Table_hedonic_tenant.tex, drop(*) f a 	noobs nomtitles nonum wrap nogaps

	esttab output1 output2 output3 using Table_hedonic_tenant.tex, drop(*) f a ///
	noobs scalars("N Observations" "r2_a R2") nomtitles nonum wrap nolines nogaps

		
** Dummies to identify different parts of the town
g all 	  = 1
g ab 	  = (zone1 == "Vika-Aker Brygge")
g fs_u_ab = ((bydel == "Sentrum" | bydel == "Frogner") & zone1 != "Vika-Aker Brygge")
g u_ab    = (bydel != "Sentrum" & bydel != "Frogner")
g vest = 0
replace vest = 1 if bydel == "Frogner" | bydel == "Gamle Oslo" | bydel == "Grünerløkka" | bydel == "Nordre Aker" | bydel == "Sagene" | bydel == "Sentrum" | bydel == "St.Hanshaugen" | bydel == "Ullern" | bydel == "Vestre Aker"
g ost        = 1 - vest
	
** Constructing hedonic indices for different sub-markets (parts of the town)
foreach var in all ab fs_u_ab u_ab vest ost {
preserve
keep if `var' == 1
tab bydel
qui reg lrent $extended_controls
cd "$dataPath"
matrix b = e(b)'
svmat b
matrix bxi = b`i'["176.contract_start_quarter_year".."235.contract_start_quarter_year",1]
svmat bxi
gen rent_index_`var'  = exp(bxi)
keep rent_index_`var'
drop if rent_index_`var' == .
gen dup = _n 
gen contract_start_quarter_year = 176
replace contract_start_quarter_year = contract_start_quarter_year + dup - 1 if dup > 1
tsset contract_start_quarter_year
format contract_start_quarter_year %tq
drop dup
tssmooth ma ma_rent_index_`var' = rent_index_`var', window(3 1 0)
save hedonic_`var', replace
line ma_rent_index_`var' contract_start_quarter_year, xtitle("") ytitle("Prisindeks")
cd "$outputFigures"
graph export index_`var'.pdf, replace
restore
} 

cd "$dataPath"
clear all
use hedonic_all
foreach var in ab fs_u_ab u_ab vest ost {
merge 1:1 contract_start_quarter_year using hedonic_`var'
drop _merge
}
save hedonic, replace


******************************************************************************************
** Estimating hedonic models year by year - comparing with hedonic model for full sample
* Full sample
clear all
cd "$dataPath"
set maxvar 32000
use data_construtced_w_metro_dist_trunc, clear

* Use comparable samples
bysort building_id : gen num_trans = _N
keep if num_trans >= 5

set matsize 10000
sort contract_start_year

* Run regressions
qui reg lrent $extended_controls
predict pred_new_alle_aar

matrix r2 = J(15,1,.)
g pred_new_year_by_year =.

** Hedonic model year-by-year
forvalues i=2004/2018 {
qui reg lrent $extended_controls if contract_start_year == `i'
predict pred_new_`i' if contract_start_year == `i'
replace pred_new_year_by_year = pred_new_`i' if contract_start_year == `i'
matrix r2[`i'-contract_start_year+1,1] = e(r2_a)
}
matrix list r2

** Correlation between predicted values from full-sample model and year-by-year model
matrix corr_pred = J(15,1,.)
forvalues i=2004/2018 {
matrix accum R = pred_new_year_by_year pred_new_alle_aar if contract_start_year == `i', noconstant deviations
matrix corr_test = corr(R)
matrix corr_pred[`i'-contract_start_year+1,1]= corr_test[2,1]
corr pred_new_year_by_year pred_new_alle_aar if contract_start_year == `i'
}

** This is the correlation coefficient  between year-by-byear and full-sample for all years 
matrix list corr_pred

** This is the correlation coefficient  between year-by-byear and full-sample for the whole sample
corr pred_new_year_by_year pred_new_alle_aar








