****** Written by Marius Hagen and André Anundsen
****** The code estimates alternative hedonic models for rental prices in the office market in Oslo. Results are saved in a table in LaTex format
****** In addition, the code estimates hedonic rental price indices for different geographical segments of the Oslo market
clear all
cd "$dataPath"
set maxvar 32000
use data_construtced_w_metro_dist_trunc, clear

** Make sure that we have comparable samples
drop if contract_sign_year == .
** Very few contracts with signature date pre 2007
keep if contract_sign_year >= 2007

** Require tenants to move in at least 30 days after signing contract
g dist = contractstart - signdate
keep if dist >= 30 

** Keeping only contracts for offices in buildings with at least 5 transactions (10th pct)
bysort building_id : gen num_trans = _N
keep if num_trans >= 5

g contract_sign_quarter_year = yq(contract_sign_year, contract_sign_quarter)
sort contract_sign_quarter_year
format contract_sign_quarter_year %tq

** Extend martix size to be able to add more controls
set matsize 10000

global contract_start i.contract_start_quarter_year lsize i.dum_private_renter contract_length_year i.renegotiated i.building_id
global contract_sign  i.contract_sign_quarter_year  lsize i.dum_private_renter contract_length_year i.renegotiated i.building_id
	
*** Regressions based on contract sign
preserve 
	sort contract_sign_quarter_year
	keep if contract_sign_quarter_year > 187 & contract_sign_quarter_year < 235

	** Extend martix size to be able to add more controls
	set matsize 10000
	sort contract_start_year

	g three_digits = (zip_code < 1000)
	g two_zip = int(zip_code/100)
	g three_zip = int(zip_code/10)

	** Only time and zip code
	global simple_controls   i.zip_code i.contract_sign_quarter_year 
	global simple_controls4  i.contract_sign_quarter_year 
	** Baseline hedonic controls
	global baseline_controls   i.zip_code i.contract_sign_quarter_year lsize i.dum_private_renter contract_length_year i.renegotiated
	** Adding distance to closest metro station to study effect of proximity to metro station
	global additional_controls i.zip_code i.contract_sign_quarter_year lsize i.dum_private_renter contract_length_year i.renegotiated shortest_dist_to_metro 
	** Controlling for building fixed effects (note: do not need zip-code FE in this case, since location of buliding is not changing --> part of building FE)
	global extended_controls i.contract_sign_quarter_year lsize i.dum_private_renter contract_length_year i.renegotiated i.building_id

	** Labeling variables for table
	label var lsize "log(Size (sq.ft.)"
	label var contract_length_year "Contract length (year)"
	label var shortest_dist_to_metro "Dist. to closest metro. (miles)"
	label define dum_private_renter 1 "Private renter"
	label val dum_private_renter dum_private_renter
	label define renegotiated 1 "Renegotiation"
	label val renegotiated renegotiated

	*** Estimating four alternative hedonic models
	qui reg lrent $simple_controls 
	eststo output1
	qui reg lrent $baseline_controls 
	eststo output2
	qui reg lrent $additional_controls
	eststo output3
	qui reg lrent $extended_controls
	eststo output4
	qui reg lrent $simple_controls4 
	eststo output7

	cd "$outputTables"
		esttab output7 output1 output2 output3 output4 using Table_hedonic_sign.tex , keep(lsize contract_length_year 1.dum_private_renter 1.renegotiated shortest_dist_to_metro ) f replace ///
		b(3) se(2) sfmt(2) noobs se label  mtitles("(I)" "(II)" "(III)" "(IV)" "V") star(* 0.10 ** 0.05 *** 0.01) nonum type     	

		esttab output7 output1 output2 output3 output4 using Table_hedonic_sign.tex, drop(*) f a 	noobs nomtitles nonum wrap nogaps

		esttab output7 output1 output2 output3 output4 using Table_hedonic_sign.tex, drop(*) f a ///
		noobs scalars("N Observations" "r2_a R2") nomtitles nonum wrap nolines nogaps
restore
	
	** Preferred model contract start - indexes (equal to extended controls)
preserve
	keep if contract_start_quarter_year > 187 & contract_start_quarter_year < 235
	sort contract_start_quarter_year
	
	qui reg lrent $contract_start
	cd "$dataPath"
	matrix b = e(b)'
	svmat b
	matrix bxi = b`i'["188.contract_start_quarter_year".."234.contract_start_quarter_year",1]
	svmat bxi
	gen rent_index_start  = exp(bxi)
	keep rent_index_start
	drop if rent_index_start == .
	gen dup = _n 
	gen contract_start_quarter_year = 188
	replace contract_start_quarter_year = contract_start_quarter_year + dup - 1 if dup > 1
	tsset contract_start_quarter_year
	format contract_start_quarter_year %tq
	drop dup
	tssmooth ma ma_rent_index_start = rent_index_start, window(3 1 0)
	save hedonic_start, replace
	line ma_rent_index_start contract_start_quarter_year, xtitle("") ytitle("Prisindeks")
	cd "$outputFigures"
	graph export index_start.pdf, replace

restore

*** Mean based on contract start
preserve 
	keep if contract_start_quarter_year > 187 & contract_start_quarter_year < 235
	sort contract_start_quarter_year

	** Identifying percentiles of some variables in every quarter
	bysort contract_start_quarter_year : egen mean_rent_start = mean(rent)
	bysort contract_start_quarter_year : gen dup = _n 
	keep if dup == 1
	tsset contract_start_quarter_year
	format contract_start_quarter_year %tq
	tssmooth ma ma_mean_rent_start = mean_rent_start , window(3 1 0)
	keep ma_mean_rent_start contract_start_quarter_year
	cd "$dataPath"
	save Mean_start, replace
	line (ma_mean_rent_start) contract_start_quarter_year ,xtitle("") ytitle("Mean rent per sqm.")
	cd "$outputFigures"
	graph export Mean_start.pdf, replace
restore

*** Index based on contract signed
preserve 
	sort contract_sign_quarter_year
	keep if contract_sign_quarter_year > 187 & contract_sign_quarter_year < 235

	qui reg lrent $contract_sign
	cd "$dataPath"
	matrix b = e(b)'
	svmat b
	matrix bxi = b`i'["188.contract_sign_quarter_year".."234.contract_sign_quarter_year",1]
	svmat bxi
	gen rent_index_sign  = exp(bxi)
	keep rent_index_sign
	drop if rent_index_sign == .
	gen dup = _n 
	gen contract_start_quarter_year = 188
	replace contract_start_quarter_year = contract_start_quarter_year + dup - 1 if dup > 1
	tsset contract_start_quarter_year
	format contract_start_quarter_year %tq
	drop dup
	tssmooth ma ma_rent_index_sign = rent_index_sign, window(3 1 0)
	save hedonic_sign, replace
	line ma_rent_index_sign contract_start_quarter_year, xtitle("") ytitle("Prisindeks")
	cd "$outputFigures"
	graph export index_sign.pdf, replace
restore
  
 *** Mean based on signature date 
preserve 
	keep if contract_sign_quarter_year > 187 & contract_sign_quarter_year < 235
	sort contract_sign_quarter_year

	bysort contract_sign_quarter_year : egen mean_rent_sign = mean(rent)
	bysort contract_sign_quarter_year : gen dup = _n 
	keep if dup == 1
	tsset contract_sign_quarter_year
	format contract_sign_quarter_year %tq
	tssmooth ma ma_mean_rent_sign = mean_rent_sign , window(3 1 0)
	keep ma_mean_rent_sign contract_sign_quarter_year
	ren contract_sign_quarter_year contract_start_quarter_year
	cd "$dataPath"
	save Mean_sign, replace
	line (ma_mean_rent_sign) contract_start_quarter_year ,xtitle("") ytitle("Mean rent per sqm.")
	cd "$outputFigures"
	graph export Mean_sign.pdf, replace
restore


g ab 	  = (zone1 == "Vika-Aker Brygge")
g fs_u_ab = ((bydel == "Sentrum" | bydel == "Frogner") & zone1 != "Vika-Aker Brygge")
g u_ab    = (bydel != "Sentrum" & bydel != "Frogner")
g vest = 0
replace vest = 1 if bydel == "Frogner" | bydel == "Gamle Oslo" | bydel == "Grünerløkka" | bydel == "Nordre Aker" | bydel == "Sagene" | bydel == "Sentrum" | bydel == "St.Hanshaugen" | bydel == "Ullern" | bydel == "Vestre Aker"
g ost        = 1 - vest

*** Index based on contract signed for some geographical segments
foreach var in ab fs_u_ab u_ab vest ost {
preserve 
	keep if `var' == 1
	keep if contract_sign_quarter_year > 187 & contract_sign_quarter_year < 235
	sort contract_sign_quarter_year

	bysort contract_sign_quarter_year : egen mean_rent_sign_`var' = mean(rent)
	bysort contract_sign_quarter_year : gen dup = _n 
	keep if dup == 1
	tsset contract_sign_quarter_year
	format contract_sign_quarter_year %tq
	tssmooth ma ma_mean_rent_sign_`var' = mean_rent_sign_`var' , window(3 1 0)
	keep ma_mean_rent_sign_`var' contract_sign_quarter_year
	ren contract_sign_quarter_year contract_start_quarter_year
	cd "$dataPath"
	save Mean_sign_`var', replace
	line (ma_mean_rent_sign_`var') contract_start_quarter_year ,xtitle("") ytitle("Mean rent per sqm.")
	cd "$outputFigures"
	graph export Mean_sign_`var'.pdf, replace
restore
}


foreach var in ab fs_u_ab u_ab vest ost {
preserve
	keep if `var' == 1
	sort contract_sign_quarter_year
	keep if contract_sign_quarter_year > 187 & contract_sign_quarter_year < 235
	qui reg lrent $contract_sign
	cd "$dataPath"
	matrix b = e(b)'
	svmat b
	matrix bxi = b`i'["188.contract_sign_quarter_year".."234.contract_sign_quarter_year",1]
	svmat bxi
	gen rent_index_sign_`var'  = exp(bxi)
	keep rent_index_sign_`var'
	drop if rent_index_sign_`var' == .
	gen dup = _n 
	gen contract_start_quarter_year = 188
	replace contract_start_quarter_year = contract_start_quarter_year + dup - 1 if dup > 1
	tsset contract_start_quarter_year
	format contract_start_quarter_year %tq
	drop dup
	tssmooth ma ma_rent_index_sign_`var' = rent_index_sign_`var', window(3 1 0)
	save hedonic_sign_`var', replace
	line ma_rent_index_sign_`var' contract_start_quarter_year, xtitle("") ytitle("Prisindeks")
	cd "$outputFigures"
	graph export index_sign_`var'.pdf, replace
restore
}

*** Merging all data sets: hedonic and mean based on contract start and sign date
cd "$dataPath"
clear all
use hedonic_start
merge 1:1 contract_start_quarter_year using hedonic_sign
drop _merge
merge 1:1 contract_start_quarter_year using Mean_start
drop _merge
merge 1:1 contract_start_quarter_year using Mean_sign
drop _merge
save start_versus_sign, replace

** Normalizing to one in 2008Q1
sum  ma_rent_index_start if contract_start_quarter_year == 192, meanonly
scalar norm_index_start = r(mean)
g ma_rent_index_start_norm = ma_rent_index_start/norm_index_start
label var ma_rent_index_start_norm "Hedonic, start date"

sum  ma_mean_rent_start if contract_start_quarter_year == 192, meanonly
scalar norm_mean_start = r(mean)
g ma_mean_rent_start_norm = ma_mean_rent_start /norm_mean_start
label var ma_mean_rent_start_norm "Mean, start date"

sum  ma_rent_index_sign if contract_start_quarter_year == 192, meanonly
scalar norm_index_sign = r(mean)
g ma_rent_index_sign_norm = ma_rent_index_sign/norm_index_sign
label var ma_rent_index_sign_norm "Hedonic, signature date"

sum  ma_mean_rent_sign if contract_start_quarter_year == 192, meanonly
scalar norm_mean_sign = r(mean)
g ma_mean_rent_sign_norm = ma_mean_rent_sign /norm_mean_sign
label var ma_mean_rent_sign_norm "Mean, signature date"

line (ma_rent_index_sign_norm ma_rent_index_start_norm) contract_start_quarter_year if  contract_start_quarter_year >= 192, lcolor(red black) lpattern(solid solid ) legend(col(2) region(lstyle(none))) xtitle("")  xla(192 208 220 232) 
cd "$outputFigures"
graph export SignVersusStart.pdf, replace

*** Merging all hedonic sign date indices into one data set, normalizing and plotting
cd "$dataPath"
clear all
use hedonic_sign
foreach var in ab fs_u_ab u_ab vest ost {
merge 1:1 contract_start_quarter_year using hedonic_sign_`var'
drop _merge
}
save indices_sign_date, replace

** Normalize to one in 2011Q1
foreach var in ab fs_u_ab u_ab vest ost {
sum  ma_rent_index_sign_`var' if contract_start_quarter_year == 204, meanonly
scalar norm_index_`var'_sign = r(mean)
g ma_rent_index_sign_norm_`var' = ma_rent_index_sign_`var'/norm_index_`var'_sign
}

** Labeling variables for chart
label var ma_rent_index_sign_norm_ab "Vika-Aker Brygge"
label var ma_rent_index_sign_norm_fs_u_ab "City Centre and Frogner, excluding Vika-Aker Brygge"
label var ma_rent_index_sign_norm_u_ab "Rest of Oslo"

** Plotting hedonic and mean based on sign. date for Vika-Aker Brygge, Frogner and Sentrum (ex. Vika-Aker Brygge) and rest of Oslo
line (ma_rent_index_sign_norm_ab ma_rent_index_sign_norm_fs_u_ab ma_rent_index_sign_norm_u_ab) contract_start_quarter_year if  contract_start_quarter_year >= 192, lcolor(red black blue) lpattern(dash solid dash) legend(col(1) region(lstyle(none))) xtitle("")  xla(192 208 220 232) 
cd "$outputFigures"
graph export AkerBrygge_hedonic_sign.pdf, replace


*** Merging all mean sign date indices into one data set, normalizing and plotting
cd "$dataPath"
clear all
use Mean_sign
foreach var in ab fs_u_ab u_ab vest ost {
merge 1:1 contract_start_quarter_year using Mean_sign_`var'
drop _merge
}
save Mean_sign_date, replace

foreach var in ab fs_u_ab u_ab vest ost {
sum  ma_mean_rent_sign_`var' if contract_start_quarter_year == 204, meanonly
scalar norm_index_`var'_sign = r(mean)
g ma_mean_rent_sign_norm_`var' = ma_mean_rent_sign_`var'/norm_index_`var'_sign
}
line (ma_mean_rent_sign_norm_ab ma_mean_rent_sign_norm_fs_u_ab ma_mean_rent_sign_norm_u_ab) contract_start_quarter_year if  contract_start_quarter_year >= 192, lcolor(red black blue) lpattern(dash solid dash) legend(off) xtitle("")  xla(192 208 220 232) 
cd "$outputFigures"
graph export AkerBrygge_mean_sign.pdf, replace



